      SUBROUTINE MAP_STEEL_PARTIC( ALTOT,ALSOL,OXYWT,OXYMIN,TITOT,
     &           PEROAL,PEROTI,PEROMN,PEROSI,PERTIN,PERTIO,PERBSL,
     &           PERBN,IFAIL,NITWT,NITSOL,BWT,STATE,FBORT )
C
      IMPLICIT NONE                          
      DOUBLE PRECISION A1,A2,ALATM,ALSOL,ALTOT,BATM,BWTSOL,BSOL
      DOUBLE PRECISION BWT,FBORT,NIT2,NIT3,NIT4,NITATM,NITB
      DOUBLE PRECISION NITPPM,NITSOL,NITTI,NITWT,OXY1,OXY2
      DOUBLE PRECISION OXY21,OXY22,OXYAL,OXYATM,OXYMIN,OXYTI 
      DOUBLE PRECISION OXYWT,PERBN,PERBSL,PEROAL,PEROMN,PEROSI
      DOUBLE PRECISION PEROTI,PERTIN,PERTIO,STAL,STATE,THETA
      DOUBLE PRECISION TI2,TI3,TIATM,TIN,TITOT
      INTEGER IFAIL
C
C ALATM aluminium, moles per 100 grams combined with oxygen
C ALSOL dissolved aluminium concentration in wt.%
C ALTOT total aluminum concentration in wt.%
C BPPM total boron concentration in ppmw by wt.
C BWT   total boron concentration in wt.%
C BATM  total boron concentration, moles per 100 grams
C FBORT temperature at which boron solubility product is evaluated
C NITPPM   total nitrogen concentration in ppmw by wt.
C NITWT total nitrogen concentration in wt.%
C NITATM total nitrogen, moles per 100g
C NITTI nitrogen combined with Ti, moles per 100g
C NITB  nitrogen combined with B,  moles per 100g
C NITSOL soluble nitrogen in ppmw
C OXYATM oxygen, moles per 100 grams
C OXYAL  oxygen moles per 100 grams, combined with Al
C OXYTI  oxygen moles per 100 grams, combined with Ti
C OXY1   oxygen left over after aluminium has reacted
C OXY2   oxygen left over after aluminium & titanium have reacted
C        Alumina = Al2O3, titania = Ti2O3 or TiO2 or TiO
C OXYMIN minimum oxygen, wt.% to combine with Al and Ti
C PEROAL  % of moles of oxygen tied up with aluminium
C PEROTI  % of moles of oxygen tied up with titanium
C PERR   % of moles of oxygen tied up with other oxides
C PERTIN % of moles of titanium tied up with nitrogen
C PERTIO % of moles of titanium tied up with oxygen
C PERBSL % of moles of boron which is in solution
C PERBN  % of moles of boron which is tied up nitride
C TITOT total titanium concentration in wt.%
C TIATM total amount of titanium in moles per 100g
C TI2   titanium left after combining with oxygen, moles per 100g
C STAL oxidation state of alumina
C STATE depends on whether Ti2O3 forms or TiO or TiO2 (Mat. Sci. & Tech. 4 
C       (1988) 58)
C If IFAIL=1, amount of oxygen is inadequate to tie up aluminium
C
      IFAIL  = 0
      STAL   = 1.5D0
      ALATM  = 0.01D0*(ALTOT-ALSOL)/26.98154D0
      TIATM  = 0.01D0*TITOT/47.90D0
      NITATM = 0.01D0*NITWT/14.0067D0
      BATM   = 0.01D0*BWT/10.81D0
      OXYATM = 0.01D0*OXYWT/15.9994D0
      OXYAL  = ALATM*STAL
      NITPPM = NITWT*1.0D4
      IF (OXYAL .GT. OXYATM) THEN
         OXYAL = OXYATM
         IFAIL = 1
      ENDIF
      OXY1   = OXYATM-OXYAL
      IF (OXY1 .LE. 0.0D+00) THEN
         PEROAL = 1.0D2
         PEROTI = 0.0D0
         PEROMN = 0.0D0
         PEROSI = 0.0D0
         OXY1   = 0.0D0
      ENDIF
      OXYTI = TIATM*STATE
      IF (OXYTI .GT. OXY1) OXYTI = OXY1
      OXY2  = OXYATM-OXYAL-OXYTI
      TI2   = TIATM-(OXYTI/STATE)
      NITTI = TI2
      IF (NITTI .GT. NITATM) NITTI = NITATM
      TIN   = NITTI
      TI3   = TI2-TIN
      NIT2  = NITATM-NITTI
C
C Soluble boron calculation.
C Solubility product from Fountain and Chipman.
C
      NITB  = BATM
      IF (NITB .GT. NIT2) THEN
         NITB = NIT2
         GOTO 110
      ENDIF
      NIT3 = NIT2
      IF (BWT .EQ. 0.0D0) THEN
         BWTSOL = 0.0D0
         GOTO 110
      ENDIF
  100 BWTSOL = (10.0D0**(5.24D0 - (13970.0D0/(FBORT+273.00))))/
     &         (NIT3*NITWT/NITATM)
      NIT4   = NIT2-(BWT-BWTSOL)*BATM/BWT
      IF (NIT4 .GT. 1.1*NIT3 .OR. NIT4 .LT. 0.9*NIT3) THEN
         NIT3 = NIT4
         GOTO 100
      ENDIF
      NITB = NIT2-NIT4
C
C End of soluble boron calculation.
C
  110 IF (NITWT .GT. 0.0D+00) THEN
         NITSOL = (NITATM-NITTI-NITB)*NITPPM/NITATM
      ELSE
         NITSOL = 0.0D0
      ENDIF
      BSOL = BATM-NITB
      IF (BSOL .LT. 0.0D0) BSOL = 0.0D0
C
C   Calculation of MnO and SiO2: SEE p.117 of book 13.
C   Value of THETA from Evans, 1990. Filed in welding inclusions.
C
      THETA = 1.64D0
      A1    = 1.0D0/(70.9374*(1.0D0 + THETA))
      A2    = 2.0D0/(60.0843*(1.0D0 + (1.0/THETA)))
      IF (OXY2 .LE. 0.0D+00) THEN
         OXY21 = 0.0D0
         OXY22 = 0.0D0
      ELSE
         OXY21 = OXY2*(A1/(A1+A2))
         OXY22 = OXY2*(A2/(A1+A2))
      ENDIF
C
C   MnO and SiO2 complete.
C
      IF (OXYATM .GT. 0.0D0) THEN
         PEROAL = 1.0D2*OXYAL /OXYATM
         PEROTI = 1.0D2*OXYTI /OXYATM
         PEROMN = 1.0D2*OXY21 /OXYATM
         PEROSI = 1.0D2*OXY22 /OXYATM
      ELSE
        PEROAL = 0.0D0
        PEROTI = 0.0D0
        PEROMN = 0.0D0
        PEROSI = 0.0D0
      ENDIF
C
      IF (TIATM .GT. 0.0D0) THEN
         PERTIN = 1.0D2*TIN/TIATM
         PERTIO = 1.0D2*((TIATM-TIN-TI3)/TIATM)
      ELSE
         PERTIN = 0.0D0
         PERTIO = 0.0D0
      ENDIF
C
      IF (BATM .GT. 0.0D+00) THEN
         PERBSL = 1.0D2*(BSOL/BATM)
         PERBN  = 1.0D2-PERBSL
      ELSE
         PERBSL = 0.0D0
         PERBN = 0.0D0
      ENDIF
C
      OXYMIN = (ALATM*STAL+TIATM*STATE)*OXYWT/OXYATM
      RETURN
      END
